@@ -91,6 +91,8 @@ sub unlockAll{
   return 1;
 }
 
+1;
+
 __DATA__
 
 =head1 NAME
@@ -105,8 +107,6 @@ Retains hash of all locks held by transaction.
 
 =head1 FUNCTIONS
 
-=back
-
 =head2 EXPORT
 
 =head1 LIMITATIONS
